@@ -1,9 +1,9 @@
 #!/bin/sh
 export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
 echo 'name: wai
-version: 3.2.0
-id: wai-3.2.0-a50c1f56084e726fac99a6d8758a9179
-key: wai_C3HptkZmQQZ3FsKfppt8bd
+version: 3.2.0.1
+id: wai-3.2.0.1-d9757c75f497737a542bd24e4c437c56
+key: wai_6Pi7BTumKrYJiMU4SY1oRL
 license: MIT
 maintainer: michael@snoyman.com
 stability: Stable
@@ -17,19 +17,19 @@ exposed: True
 exposed-modules:
     Network.Wai Network.Wai.Internal
 trusted: False
-import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
-library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0
-data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.0
-hs-libraries: HSwai-3.2.0-C3HptkZmQQZ3FsKfppt8bd
+import-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0.1
+library-dirs: /usr/lib/ghc-7.10.3/site-local/wai-3.2.0.1
+data-dir: /usr/share/arm-linux-ghc-7.10.3/wai-3.2.0.1
+hs-libraries: HSwai-3.2.0.1-6Pi7BTumKrYJiMU4SY1oRL
 depends:
     base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
-    blaze-builder-0.4.0.1-adef087994cafeb1970772b79d5f710a
+    blaze-builder-0.4.0.1-0c3e4ae1ea19a65d81d24f4a911c903b
     bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
-    http-types-0.9-26f1bedc2b9255e48a8e673fef6095b1
+    http-types-0.9-a274b17bf4f057225e6c0af6d57f03ec
     network-2.6.2.1-602ee4a12c5a174f6683a75303a065d3
-    text-1.2.1.3-6c3c87c392cdf2c29fca1c10bbf7250b
+    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
     transformers-0.4.2.0-252429dba576bc247c1932da496e0a3f
-    vault-0.3.0.5-120c06b68c7b54723ea533fbac9dc558
+    vault-0.3.0.6-2c2444df5306907b16aaa509d25c29c9
 haddock-interfaces: /usr/share/doc/haskell-wai/html/wai.haddock
 haddock-html: /usr/share/doc/haskell-wai/html
 ' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
